package eu.etaxonomy.taxeditor.prototype2.view;

import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.FocusEvent;
import org.eclipse.swt.events.FocusListener;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.ExpandBar;
import org.eclipse.swt.widgets.ExpandItem;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.part.ViewPart;

import com.swtdesigner.ResourceManager;
import com.swtdesigner.SWTResourceManager;

import eu.etaxonomy.taxeditor.prototype2.Activator;

/**
 * @author p.ciardelli
 *
 */
public class NameListView extends ViewPart {
	
	private Text searchText;
	private Composite composite;
	private Composite taxTreeComposite = null;
	private Composite recentNamesComposite = null;
	private Composite searchComposite = null;	
	private Composite top = null;
	private ExpandBar expandBar = null;
	private ExpandItem taxTreeExpandItem;
	private ExpandItem recentNamesExpandItem;
	private ExpandItem searchExpandItem;
	private TableViewer recentNamesViewer;	
	public static final String ID = "eu.etaxonomy.taxeditor.prototype2.view.namelistview"; //$NON-NLS-1$

	private TreeViewer treeViewer;
	
	/**
	 * Create contents of the view part
	 * @param parent
	 */
	@Override
	public void createPartControl(Composite parent) {
		
		parent.setLayout(new FillLayout());
		GridLayout gridLayout = new GridLayout();
		gridLayout.horizontalSpacing = 0;
		gridLayout.marginWidth = 0;
		gridLayout.marginHeight = 0;
		gridLayout.verticalSpacing = 0;	
				
		top = new Composite(parent, SWT.NONE);
		top.setBackground(Display.getCurrent().getSystemColor(SWT.COLOR_WHITE));

		composite = new Composite(top, SWT.NONE);
		composite.setBackground(Display.getCurrent().getSystemColor(SWT.COLOR_WHITE));
		final GridLayout gridLayout_1 = new GridLayout();
		gridLayout_1.numColumns = 2;
		composite.setLayout(gridLayout_1);
		final Label lblDataSourceTitle = new Label(composite, SWT.NONE);
		lblDataSourceTitle.setFont(SWTResourceManager.getFont("Arial", 14, SWT.BOLD));
		lblDataSourceTitle.setBackground(Display.getCurrent().getSystemColor(SWT.COLOR_WHITE));
		lblDataSourceTitle.setAlignment(SWT.CENTER);
		lblDataSourceTitle.setText(" Euro+Med");		
		
		final Label lblDbImg = new Label(composite, SWT.NONE);
		lblDbImg.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false));
		lblDbImg.setBackground(Display.getCurrent().getSystemColor(SWT.COLOR_WHITE));
		lblDbImg.setImage(ResourceManager.getPluginImage(Activator.getDefault(), "icons/db.gif"));

		final Menu menu = new Menu(lblDbImg);
		lblDbImg.setMenu(menu);

		final MenuItem checkboxMenuItem = new MenuItem(menu, SWT.CHECK);
		checkboxMenuItem.setSelection(true);
		checkboxMenuItem.setText("Euro+Med (mssql://128.14.101.12:80/europlusmed)");

		final MenuItem checkboxMenuItem_1 = new MenuItem(menu, SWT.CHECK);
		checkboxMenuItem_1.setText("WP6 (mssql://128.14.101.13:80/wp6)");

		final MenuItem palmWebora1922299480pwMenuItem = new MenuItem(menu, SWT.NONE);
		palmWebora1922299480pwMenuItem.setText("Palm Web (ora://192.22.99.4:80/pw)");

		new MenuItem(menu, SWT.SEPARATOR);

		final MenuItem newDataSourceMenuItem = new MenuItem(menu, SWT.NONE);
		newDataSourceMenuItem.setText("New data source ...");
		
		final Label lblDataSource = new Label(composite, SWT.NONE);
		final GridData gd_lblDataSource = new GridData(SWT.LEFT, SWT.CENTER, false, false, 2, 1);
		gd_lblDataSource.heightHint = 16;
		lblDataSource.setLayoutData(gd_lblDataSource);
		lblDataSource.setFont(SWTResourceManager.getFont("Arial", 8, SWT.NONE));
		lblDataSource.setBackground(Display.getCurrent().getSystemColor(SWT.COLOR_WHITE));
		lblDataSource.setAlignment(SWT.CENTER);
		lblDataSource.setText("  mssql://128.14.101.12:80/europlusmed");

		createExpandBar();
		top.setLayout(gridLayout);
		top.setTabList(new Control[] {composite, expandBar});
	}

	/**
	 * This method initializes expandBar
	 * 
	 */
	private void createExpandBar() {
		expandBar = new ExpandBar(top, SWT.V_SCROLL);
		GridData gridData = new GridData();
		gridData.horizontalAlignment = GridData.FILL;
		gridData.grabExcessHorizontalSpace = true;
		gridData.grabExcessVerticalSpace = true;
		gridData.verticalAlignment = GridData.FILL;
		expandBar.setLayoutData(gridData);
		createNameListComposite();
		createRecentNamesComposite();
		createSearchComposite();
		
		createActions();
		initializeToolBar();
		initializeMenu();
		
	}
	
	private void createNameListComposite() {
		taxTreeExpandItem = new ExpandItem(expandBar, SWT.NONE, 0);
		taxTreeExpandItem.setExpanded(true);
		taxTreeExpandItem.setHeight(200);
		taxTreeExpandItem.setText("Taxonomic Tree");
		
		taxTreeComposite = new Composite(expandBar, SWT.NONE);
		taxTreeComposite.setLayout(new FillLayout());
		taxTreeComposite.setBackground(Display.getCurrent().getSystemColor(SWT.COLOR_WHITE));
		
		taxTreeExpandItem.setControl(taxTreeComposite);

		treeViewer = new TaxonomicTreeViewer(taxTreeComposite);
	}
	
	private void createRecentNamesComposite() {
		recentNamesExpandItem = new ExpandItem(expandBar, SWT.NONE, 1);
		recentNamesExpandItem.setHeight(130);
		recentNamesExpandItem.setExpanded(true);
		recentNamesExpandItem.setText("Recently viewed names");
		recentNamesComposite = new Composite(expandBar, SWT.NONE);
		recentNamesComposite.setLayout(new GridLayout());

		recentNamesExpandItem.setControl(recentNamesComposite);

		recentNamesViewer = new RecentNamesTableViewer(recentNamesComposite);
	}

	private void createSearchComposite() {
		searchExpandItem = new ExpandItem(expandBar, SWT.NONE, 2);
		searchExpandItem.setHeight(50);
		searchExpandItem.setExpanded(true);
		searchExpandItem.setText("Search");
		searchComposite = new Composite(expandBar, SWT.NONE);
		final GridLayout gridLayout = new GridLayout();
		gridLayout.numColumns = 2;
		searchComposite.setLayout(gridLayout);

		searchExpandItem.setControl(searchComposite);

		searchText = new Text(searchComposite, SWT.BORDER);
		searchText.setForeground(SWTResourceManager.getColor(192, 192, 192));
		searchText.setText("Use \"*\" for wildcard searching");
		final GridData gd_useForText = new GridData(SWT.FILL, SWT.CENTER, true, false);
		searchText.setLayoutData(gd_useForText);
		searchText.addFocusListener(new FocusListener() {

			public void focusGained(FocusEvent e) {
				searchText.setForeground(SWTResourceManager.getColor(0,0,0));
				searchText.setText("");
			}

			public void focusLost(FocusEvent e) {
				if (searchText.getText() == "") {
					searchText.setForeground(SWTResourceManager.getColor(192, 192, 192));
					searchText.setText("Use \"*\" for wildcard searching");					
				}
				
			}
			
		});

		final Button searchButton = new Button(searchComposite, SWT.NONE);
		searchButton.setText("Search");

//		Image image = FileArrangerImages.getImageRegistry().get(
//				IFileArrangerImages.IMG_FTP);
//		ftpExpandItem.setImage(image);
	}	
	
	private void createActions() {
		// Create the actions
	}

	/**
	 * Initialize the toolbar
	 */
	private void initializeToolBar() {
		IToolBarManager toolbarManager = getViewSite().getActionBars()
				.getToolBarManager();
	}

	/**
	 * Initialize the menu
	 */
	private void initializeMenu() {
		IMenuManager menuManager = getViewSite().getActionBars()
				.getMenuManager();
	}

	@Override
	public void setFocus() {
		// Set the focus
	}

	/**
	 * Expose TreeViewer, i.e. to manipulate tree nodes
	 * @return
	 */
	public TreeViewer getTreeViewer() {
		return treeViewer;
	}
	
}
