// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.actions.images;

import java.net.URL;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.operations.IUndoableOperation;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.resource.ImageDescriptor;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.ITaxEditorConstants;
import eu.etaxonomy.taxeditor.TaxEditorPlugin;
import eu.etaxonomy.taxeditor.controller.EditorController;
import eu.etaxonomy.taxeditor.controller.GlobalController;
import eu.etaxonomy.taxeditor.operations.images.RemoveImageOperation;

/**
 * @author p.ciardelli
 * @created 31.03.2009
 * @version 1.0
 */
public class RemoveImageAction extends Action {
	private static final Logger logger = Logger
			.getLogger(RemoveImageAction.class);
	
	private static final String text = "Remove image from taxon"; //$NON-NLS-1$
	private static final ImageDescriptor image = TaxEditorPlugin.getDefault()
			.getImageDescriptor(ITaxEditorConstants.ACTIVE_DELETE_ICON);	
	
	private Taxon taxon;
	private URL url;
	
	/**
	 * 
	 */
	private RemoveImageAction() {
		super(text, image);
	}
	
	/**
	 * @param taxon
	 * @param url
	 */
	public RemoveImageAction(Taxon taxon, URL url) {
		this();
		
		this.taxon = taxon;
		this.url = url;
	}

	public void run() {
		IUndoableOperation operation = new RemoveImageOperation
				(this.getText(), EditorController.getUndoContext(taxon), taxon, url);
		
		GlobalController.executeOperation(operation);				
	}
}
