// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.images;

import java.net.URL;
import java.util.Set;

import org.apache.log4j.Logger;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorSite;
import org.eclipse.ui.PartInitException;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.controller.EditorController;
import eu.etaxonomy.taxeditor.editor.AbstractTaxonEditor;
import eu.etaxonomy.taxeditor.editor.FreeTextElementFactory;
import eu.etaxonomy.taxeditor.editor.GroupComposite;
import eu.etaxonomy.taxeditor.editor.GroupedComposite;

/**
 * @author p.ciardelli
 * @created 30.03.2009
 * @version 1.0
 */
public class TaxonImagesEditor extends AbstractTaxonEditor {
	private static final Logger logger = Logger
			.getLogger(TaxonImagesEditor.class);
		
	public void init(IEditorSite site, IEditorInput input)
			throws PartInitException {
				
		super.init(site, input);
		
		Taxon taxon = getTaxon();	
		EditorController.addImagesEditor(taxon, this);
	}
	
	@Override
	protected void createManagedForm(Composite composite) {
		
		super.createManagedForm(composite);
		
		if (getUrls().size() == 0) {
			firstGroupedComposite = (GroupedComposite) FreeTextElementFactory.getDefault().createTaxonHasNoImagesElement(managedForm, getTaxon());
		} else {
			firstGroupedComposite = null;
			for (URL url : getUrls()) {
				Composite imageComposite = FreeTextElementFactory.getDefault().createImageElement(managedForm, getTaxon(), url);
			
				if (firstGroupedComposite == null) {
					firstGroupedComposite = (GroupedComposite) imageComposite;
				}
				
			}
		}

		setFocus();
		
		// Redraw composite
		composite.layout();
	}
	
	/**
	 * @return 
	 * 
	 */
	private Set<URL> getUrls() {
		Taxon taxon = getTaxon();
		return ImagesController.getTaxonImageUrls(taxon);
	}

	/**
	 * @return
	 */
	public GroupComposite getImageGroup() {
		for(Composite c : getAllComposites()){
			if(c instanceof ImagesGroupComposite){
				return (GroupComposite) c;
			}
		}
		return null;
	}
}