/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.operations.name;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;

import eu.etaxonomy.cdm.model.reference.ReferenceBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationship;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationshipType;
import eu.etaxonomy.taxeditor.operations.AbstractEditorOperation;

/**
 * @author p.ciardelli
 * @created 16.01.2009
 * @version 1.0
 */
public class RemoveMisappliedNameOperation extends AbstractEditorOperation {
	private static final Logger logger = Logger
			.getLogger(RemoveMisappliedNameOperation.class);
	
	private Taxon misappliedName;

	private ReferenceBase citation;

	private String microcitation;

	public RemoveMisappliedNameOperation(String label, IUndoContext undoContext,
			Taxon taxon, Taxon misappliedName) {
		super(label, undoContext, taxon);
		
		this.misappliedName = misappliedName;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus execute(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {

		// Find misapplication relation, save citation information
		for (TaxonRelationship relationship : taxon.getTaxonRelations()) {
			if (relationship.getType().equals(TaxonRelationshipType.MISAPPLIED_NAME_FOR())
					&& relationship.getFromTaxon().equals(misappliedName)) {
				citation = relationship.getCitation();
				microcitation = relationship.getCitationMicroReference();
			}
		}
		
		// Remove misapplied name relation from taxon
		taxon.removeTaxon(misappliedName, TaxonRelationshipType.MISAPPLIED_NAME_FOR());
				
		return redrawOpenEditor();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus redo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		return execute(monitor, info);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus undo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		taxon.addMisappliedName(misappliedName, citation, microcitation);
		
		return redrawOpenEditor();
	}
}
