// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.annotatedlineeditor;

import java.util.ArrayList;

import org.apache.log4j.Logger;
import org.eclipse.jface.text.BadLocationException;
import org.eclipse.jface.text.IDocument;
import org.eclipse.jface.text.IRegion;
import org.eclipse.jface.text.ITypedRegion;
import org.eclipse.jface.text.TextAttribute;
import org.eclipse.jface.text.TypedRegion;
import org.eclipse.jface.text.rules.IPartitionTokenScanner;
import org.eclipse.jface.text.rules.IToken;
import org.eclipse.jface.text.rules.Token;
import org.eclipse.jface.text.source.ISourceViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Display;

/**
 * IPartitionScanner would lead you to believe that all parts of a document must be accounted for in ITokens
 * and returned in order. However, this still proved buggy, and the slightly more obtuse SupplementalTextScanner
 * should be used instead. 
 * 
 * @author p.ciardelli
 * @created 28.10.2009
 * @version 1.0
 * @deprecated
 * @see SupplementalTextScanner
 */
public class CopyOfSupplementalTextScanner implements IPartitionTokenScanner {	
	private static final Logger logger = Logger
			.getLogger(CopyOfSupplementalTextScanner.class);
	
	private ILineDisplayStrategy lineDisplayStrategy;
	private ISourceViewer sourceViewer;

	private IToken supplementalTextToken;
	private ArrayList<ITypedRegion> supplementalTextRegions;
	private int regionsIndex;
	
	private static final String SUPPLEMENTAL = "_supplemental";
	private static final String UNDEFINED = "_undefined";

	private int tokenOffset;
	private int tokenLength;
	
	/**
	 * @param sourceViewer
	 * @param lineDisplayStrategy
	 */
	public CopyOfSupplementalTextScanner(ISourceViewer sourceViewer, ILineDisplayStrategy lineDisplayStrategy) {
		this.sourceViewer = sourceViewer;
		this.lineDisplayStrategy = lineDisplayStrategy;
		
		TextAttribute textAttribute = new TextAttribute(Display.getCurrent().getSystemColor(SWT.COLOR_DARK_GRAY), null, SWT.ITALIC);
		supplementalTextToken = new Token(textAttribute);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.text.rules.ITokenScanner#getTokenLength()
	 */
	public int getTokenLength() {
		return tokenLength;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.text.rules.ITokenScanner#getTokenOffset()
	 */
	public int getTokenOffset() {
		return tokenOffset;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.text.rules.ITokenScanner#nextToken()
	 */
	public IToken nextToken() {
		if (regionsIndex < supplementalTextRegions.size()) {
			tokenOffset = supplementalTextRegions.get(regionsIndex).getOffset();
			tokenLength = supplementalTextRegions.get(regionsIndex).getLength();
			IToken token = supplementalTextRegions.get(regionsIndex).getType().equals(SUPPLEMENTAL) ? supplementalTextToken : Token.UNDEFINED; 
			regionsIndex++;
			return token;
		}
		return Token.EOF;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.text.rules.ITokenScanner#setRange(org.eclipse.jface.text.IDocument, int, int)
	 */
	public void setRange(IDocument document, int offset, int length) {
		setPartialRange(document, offset, length, null, -1);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.text.rules.IPartitionTokenScanner#setPartialRange(org.eclipse.jface.text.IDocument, int, int, java.lang.String, int)
	 */
	public void setPartialRange(IDocument document, int offset, int length,
			String contentType, int partitionOffset) {
		
		LineAnnotationModel model = (LineAnnotationModel) sourceViewer.getAnnotationModel();
		supplementalTextRegions = new ArrayList<ITypedRegion>();
		regionsIndex = 0;
		
		ITypedRegion supplementalTextRegion = null;
		try {
			int lineCount = document.getNumberOfLines(offset, length);
			int lineStart = document.getLineOfOffset(offset);
			for (int i = lineStart; i < lineStart + lineCount; i++) {
				LineAnnotation annotation = (LineAnnotation) model.getAnnotationAtLine(i, document);
				if (annotation != null) {
					String supplementalText = lineDisplayStrategy.getSupplementalText(annotation.getEntity());
					if (supplementalText != null && supplementalText.length() > 0) {
						IRegion lineInfo = document.getLineInformation(i);
						String lineText = document.get(lineInfo.getOffset(), lineInfo.getLength());
						int supplementalTextLineOffset = lineText.indexOf(supplementalText);
						if (supplementalTextLineOffset > -1) {
							int supplementalTextOffset = lineInfo.getOffset() + supplementalTextLineOffset;
							if (supplementalTextRegion == null) {
								supplementalTextRegions.add(new TypedRegion(0, supplementalTextOffset, UNDEFINED));
							} else {
								int endLastRegion = supplementalTextRegion.getOffset() + supplementalTextRegion.getLength();
								supplementalTextRegions.add(new TypedRegion(endLastRegion, supplementalTextOffset - endLastRegion, UNDEFINED));
							}
							supplementalTextRegion = new TypedRegion(lineInfo.getOffset() + supplementalTextLineOffset, supplementalText.length(), SUPPLEMENTAL);
							supplementalTextRegions.add(supplementalTextRegion);
						}
					}
				}
			}		
		} catch (BadLocationException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
}
