/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor;

import java.util.Vector;

import org.apache.log4j.Logger;

import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Synonym;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.cdm.persistence.hibernate.CdmDataChangeEvent;
import eu.etaxonomy.cdm.persistence.hibernate.CdmDataChangeMap;
import eu.etaxonomy.cdm.persistence.hibernate.CdmDataChangeEvent.EventType;
import eu.etaxonomy.taxeditor.model.AbstractDataChangeBehaviour;
import eu.etaxonomy.taxeditor.model.IDataChangeBehavior;

/**
 * Implementation if {@link eu.etaxonomy.taxeditor.store.model.IDataChangeBehaviour} 
 * for the {@link eu.etaxonomy.taxeditor.editor.MultiPageTaxonEditor}.
 * 
 * TODO make this class a bean and thus configurable by Spring
 * 
 * @author n.hoffmann
 * @created 01.04.2009
 * @version 1.0
 */
public class MultiPageTaxonEditorDataChangeBehaviour extends AbstractDataChangeBehaviour implements
		IDataChangeBehavior {
	private static final Logger logger = Logger
			.getLogger(MultiPageTaxonEditorDataChangeBehaviour.class);

	private MultiPageTaxonEditor source;

	private TaxonEditorInput input;
	
	public MultiPageTaxonEditorDataChangeBehaviour(
			MultiPageTaxonEditor multiPageTaxonEditor) {
		source = multiPageTaxonEditor;
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.store.model.IDataChangeBehavior#reactOnDataChange()
	 */
	public void reactOnDataChange(CdmDataChangeMap changeEvents) {
		input = (TaxonEditorInput) source.getEditorInput();
		
		// I don't know when this happens but ...
		if(input.getTaxon() == null)
			return;
		
		if(changeEvents.sizeByEventType(EventType.UPDATE) > 0){
			reactOnUpdate(changeEvents.getEvents(EventType.UPDATE));
		}
		if(changeEvents.sizeByEventType(EventType.INSERT) > 0){
			reactOnInsert(changeEvents.getEvents(EventType.INSERT));
		}
		if(changeEvents.sizeByEventType(EventType.DELETE) > 0){
			reactOnDelete(changeEvents.getEvents(EventType.DELETE));
		}
	}
	
	
	@Override
	public void reactOnDelete(Vector<CdmDataChangeEvent> events){
		for(CdmDataChangeEvent event : events){
			// close open editors
			if(event.getEntity() instanceof TaxonNode){
				logger.warn("taxon node");
			}
			if((event.getEntity() instanceof TaxonNode) 
					&& input.getTaxonNode().equals(event.getEntity())){
				EditorUtil.close(source);
				logger.debug("Closing open editor for deleted taxon.");
			}
		}
	}
	
	@Override
	public void reactOnUpdate(Vector<CdmDataChangeEvent> events){

		for(CdmDataChangeEvent event : events){
			
			// update editor title
			if(event.getEntity() instanceof TaxonNameBase){
				if(input.getTaxon().getName().equals(event.getEntity())){
					// set the name of the editor window
					source.setPartName();
					logger.debug("Updating title of taxons editor.");
				}
			}
			// TODO other stuff to happen
			
		}
	}
	
	@Override
	public void reactOnInsert(Vector<CdmDataChangeEvent> events){
		boolean doRedraw = false;
		for(CdmDataChangeEvent event : events){
			// refresh on synonym changes
			if(input.getTaxon().hasSynonyms() && event.getEntity() instanceof Synonym){
				Synonym synonym = (Synonym) event.getEntity();
				
				if(synonym.isSynonymOf(input.getTaxon())){
					doRedraw = true;
					break;
				}
			}
		}
//		if(doRedraw)
//			source.redraw(Page.NAME);
	}
}
