/**
 * 
 */
package eu.etaxonomy.taxeditor.editor.descriptiontree.detailpage;

import java.awt.Color;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import org.apache.log4j.Logger;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ControlAdapter;
import org.eclipse.swt.events.ControlEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;

import eu.etaxonomy.cdm.ext.EditGeoServiceUtilities;
import eu.etaxonomy.cdm.model.description.DescriptionElementBase;
import eu.etaxonomy.cdm.model.description.Distribution;
import eu.etaxonomy.cdm.model.description.PresenceAbsenceTermBase;
import eu.etaxonomy.cdm.model.description.TaxonDescription;
import eu.etaxonomy.taxeditor.editor.descriptiontree.TaxonDescriptionFeature;
import eu.etaxonomy.taxeditor.forms.ImageComposite;

/**
 * @author nho
 *
 */
public class DistributionMapDetailsSection extends AbstractDescriptionDetailSection {

	private static final Logger logger = Logger.getLogger(DistributionMapDetailsSection.class);

	
	private ImageComposite imageComposite;
	
	/**
	 * @param parent
	 * @param page
	 * @param style
	 */
	public DistributionMapDetailsSection(Composite parent,
			AbstractDescriptionDetailsPage page, int style) {
		super(parent, page, style);

		setText("Distribution Overview"); //$NON-NLS-1$
		
		imageComposite = toolkit.createImageComposite(getClient(), null, SWT.WRAP);
		imageComposite.addControlListener(new ControlAdapter() {
			/* (non-Javadoc)
			 * @see org.eclipse.swt.events.ControlAdapter#controlResized(org.eclipse.swt.events.ControlEvent)
			 */
			@Override
			public void controlResized(ControlEvent e) {
				updateSection();
			}
		});
		imageComposite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.descriptiontree.detailpage.AbstractDescriptionDetailSection#updateSection()
	 */
	@Override
	public void updateSection() {
		try {
			imageComposite.setImageUri(this.getImageUri());
		} catch (URISyntaxException e) {
			logger.error("Error while building the uri for map webservice.", e);
		}
	}

	/**
	 * @return
	 * @throws URISyntaxException 
	 */
	private URI getImageUri() throws URISyntaxException {
		// FIXME make these hardcoded parameters configurable via preferences
		String accessPoint = "http://edit.csic.es/v1/areas.php";
		Map<PresenceAbsenceTermBase<?>,Color> presenceAbsenceTermColors = null;
		// FIXME due to a bug in the rest map service we have to ensure that width will always be an even number
		int width = imageComposite.calculateWidth() % 2 == 1 ? imageComposite.calculateWidth() + 1 : imageComposite.calculateWidth();
		
		String bbox = "-180,-90,180,90"; 
		String backLayer = null;

		String parameter = EditGeoServiceUtilities.getEditGeoServiceUrlParameterString(getDistributions(),
				presenceAbsenceTermColors, 0, 0, null, "tdwg4");
		
		return new URI(accessPoint + "?" + parameter + "&bbox=" + bbox + "&ms=" + width );
	}
	
	/**
	 * @return
	 */
	private Set<Distribution> getDistributions() {
		HashSet<Distribution> distributions = new HashSet<Distribution>();
		TaxonDescription description = ((TaxonDescriptionFeature) page.input).getDescription();
		for (DescriptionElementBase element : description.getElements()) {
			if (element instanceof Distribution) {
				distributions.add((Distribution) element);
			}
		}
		return distributions;
	}

}
