/**
 * 
 */
package eu.etaxonomy.taxeditor.editor.name.handler;

import org.apache.log4j.Logger;
import org.eclipse.jface.action.IContributionItem;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.actions.CompoundContributionItem;
import org.eclipse.ui.menus.CommandContributionItem;
import org.eclipse.ui.menus.CommandContributionItemParameter;

import eu.etaxonomy.cdm.model.name.NameRelationshipType;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.taxeditor.labels.ILabelImageStrategy;
import eu.etaxonomy.taxeditor.labels.LabelImageProvider;
import eu.etaxonomy.taxeditor.propertysheet.name.TaxonBasePropertySource;

/**
 * @author p.ciardelli
 *
 */
public class GroupBasionymContributionItem extends CompoundContributionItem {
	private static final Logger logger = Logger.getLogger(GroupBasionymContributionItem.class);

	/**
	 * 
	 */
	public GroupBasionymContributionItem() {}

	/**
	 * @param id
	 */
	public GroupBasionymContributionItem(String id) {
		super(id);
	}
	

	/* (non-Javadoc)
	 * @see org.eclipse.ui.actions.CompoundContributionItem#getContributionItems()
	 */
	@Override
	protected IContributionItem[] getContributionItems() {
		
		TaxonNameBase name = getNameFromSelection();
		
		IWorkbenchWindow window = PlatformUI.getWorkbench().getActiveWorkbenchWindow();
		CommandContributionItemParameter parameter = 
			new CommandContributionItemParameter(
					window, null, getCommand(name), SWT.NONE);
		
		parameter.label = getLabel(name);		
				
		return new IContributionItem[] {
				new CommandContributionItem(parameter)
		};
	}

	/**
	 * @param name
	 * @return
	 */
	private String getCommand(TaxonNameBase name) {
		return name.isGroupsBasionym() ?
			"eu.etaxonomy.taxeditor.editor.name.removeBasionym" :
			"eu.etaxonomy.taxeditor.editor.name.setBasionym";	
	}

	/**
	 * @param name
	 * @return
	 */
	private String getLabel(TaxonNameBase name) {
		ILabelImageStrategy strategy = LabelImageProvider.getLabelStrategy(name);
		LabelImageProvider labelProvider = new LabelImageProvider(strategy);
		return (name.isGroupsBasionym() ? "Remove" : "Set")
			+ " as " + labelProvider.getNameRelationTypeDescription(NameRelationshipType.BASIONYM()) + " for Group";
	}

	/**
	 * @return
	 */
	private TaxonNameBase getNameFromSelection() {
    	IWorkbenchWindow window = PlatformUI.getWorkbench().getActiveWorkbenchWindow();
    	Object selection = ((StructuredSelection) window.getSelectionService().getSelection()).getFirstElement();
    	TaxonNameBase name = null;
    	if (selection instanceof TaxonBasePropertySource) {
    		name = ((TaxonBasePropertySource) selection).getTaxonBase().getName();
    	}
    	if (selection instanceof TaxonBase) {
    		name = ((TaxonBase) selection).getName();
    	}
    	return name;
	}
}