// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.forms;

import org.apache.log4j.Logger;
import org.eclipse.jface.util.IPropertyChangeListener;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.joda.time.DateTime;

import eu.etaxonomy.cdm.common.CdmUtils;
import eu.etaxonomy.cdm.model.common.User;
import eu.etaxonomy.cdm.model.common.VersionableEntity;

/**
 * @author n.hoffmann
 * @created Nov 5, 2009
 * @version 1.0
 */
public class CdmComposite extends AbstractFormComposite {

	private static final Logger logger = Logger.getLogger(CdmComposite.class);
	private Label label_created;
	private Label label_createdBy;
	private Label label_updated;
	private Label label_updatedBy;
	private Label label_uuid;
	
	/**
	 * @param parent
	 * @param listener
	 * @param style
	 */
	public CdmComposite(Composite parent, VersionableEntity entity, IPropertyChangeListener listener,
			int style) {
		super(parent, listener, style);
		this.setLayout(new GridLayout(2, false));
		
		toolkit.createLabel(this, "Created:");
		label_created = toolkit.createLabel(this, null);
		label_created.setLayoutData(FILL_GRID_HORIZONTALLY());
		
		toolkit.createLabel(this, "Created by:");
		label_createdBy = toolkit.createLabel(this, null);
		label_createdBy.setLayoutData(FILL_GRID_HORIZONTALLY());
		
		toolkit.createLabel(this, "Updated:");
		label_updated = toolkit.createLabel(this, null);
		label_updated.setLayoutData(FILL_GRID_HORIZONTALLY());
		
		toolkit.createLabel(this, "Updated by:");
		label_updatedBy = toolkit.createLabel(this, null);
		label_updatedBy.setLayoutData(FILL_GRID_HORIZONTALLY());
		
//		toolkit.createLabel(this, "Uuid:");
//		label_uuid = toolkit.createLabel(this, null);
//		label_uuid.setLayoutData(FILL_GRID_HORIZONTALLY());
	}
	
	public void setEntity(VersionableEntity entity){
		if(entity.getCreated() != null)
			label_created.setText(dateFormat(entity.getCreated()));
		if(entity.getCreatedBy() != null)
			label_createdBy.setText(userFormat(entity.getCreatedBy()));
		if(entity.getUpdated() != null)
			label_updated.setText(dateFormat(entity.getUpdated()));
		if(entity.getUpdatedBy() != null)
			label_updatedBy.setText(userFormat(entity.getUpdatedBy()));
//		label_uuid.setText(entity.getUuid().toString());
	}
	
	private String dateFormat(DateTime dateTime){
		// TODO agree on pattern or get pattern via preferences or locale
		String pattern = null;
		return CdmUtils.Nz(dateTime.toString(pattern));
	}
	
	private String userFormat(User user){
		// TODO agree on what to display username or real name or even more from shibboleth
		return CdmUtils.Nz(user.getUsername());
	}
}
