/**
 * 
 */
package eu.etaxonomy.taxeditor.forms;

import org.eclipse.jface.util.IPropertyChangeListener;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.common.CdmUtils;

/**
 * @author nho
 *
 */
public class TextWithLabelComposite extends AbstractFormComposite implements ModifyListener{
	protected Text text;
	
	public TextWithLabelComposite(Composite parent, String labelString, String initialText, IPropertyChangeListener listener, boolean scroll, int style) {
		super(parent, listener, style);
		
		this.setLayoutData(new GridData(SWT.FILL, SWT.TOP, true, false));
		
		if(labelString != null){
			toolkit.createLabel(this, labelString, SWT.WRAP);
		}
		
		int scrollStyle = scroll ? SWT.V_SCROLL : SWT.NULL;
		text = toolkit.createText(this, "", SWT.BORDER | SWT.MULTI | SWT.WRAP | scrollStyle);
		text.setLayoutData(new GridData(SWT.FILL, SWT.TOP, true, false));
		text.addModifyListener(this);
		
		setText(initialText);
	}
	
	/**
	 * @param parent
	 * @param style
	 */
	public TextWithLabelComposite(Composite parent, String labelString, String initialText, IPropertyChangeListener listener,  int style) {
		this(parent, labelString, initialText, listener, false, style);
	}

	/**
	 * Get the text of this composites text composite
	 * 
	 * @return
	 */
	public String getText() {
		return text.getText();
	}

	/**
	 * Set the text of this composites text composite
	 * 
	 * @param string
	 */
	public void setText(String string) {
		Listener[] listeners = text.getListeners(SWT.Modify);
		
		for(Listener listener :  listeners){
			text.removeListener(SWT.Modify, listener);
		}
		
		text.setText(CdmUtils.Nz(string));
		
		for(Listener listener :  listeners){
			text.addListener(SWT.Modify, listener);
		}
	}

	/* (non-Javadoc)
	 * @see org.eclipse.swt.events.ModifyListener#modifyText(org.eclipse.swt.events.ModifyEvent)
	 */
	public void modifyText(ModifyEvent e) {
		firePropertyChangeEvent(null);
	}
}
