/**
 * 
 */
package eu.etaxonomy.taxeditor.forms.entitysections;

import java.util.Set;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.util.IPropertyChangeListener;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;

import eu.etaxonomy.cdm.model.common.AnnotatableEntity;
import eu.etaxonomy.cdm.model.common.Marker;

/**
 * @author nho
 *
 */
public class MarkerSection extends AbstractEntitySetSection<AnnotatableEntity> {

	/**
	 * @param parent
	 * @param entity
	 * @param style
	 */
	public MarkerSection(Composite parent, AnnotatableEntity entity, IPropertyChangeListener listener, int style) {
		super(parent, entity, "Marker", listener, style);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.forms.AbstractEntitySetSection#createDynamicContents()
	 */
	@Override
	protected void createDynamicContents() {
		Set<Marker> markers = null;
		if(getEntity() != null){
			markers = getEntity().getMarkers();
		}
		
		if(markers == null || markers.size() == 0){
			toolkit.createLabel(container, "No markers yet.");
		}else{
			for(Marker marker : markers){
				new MarkerComposite(container, marker, new RemoveListener(marker), this, SWT.NULL);
			}
		}
	}
	
	private class RemoveListener extends SelectionAdapter{
		private Marker marker;
		
		public RemoveListener(Marker marker){
			this.marker = marker;
		}
		
		/* (non-Javadoc)
		 * @see org.eclipse.swt.events.SelectionAdapter#widgetSelected(org.eclipse.swt.events.SelectionEvent)
		 */
		@Override
		public void widgetSelected(SelectionEvent e) {
			getEntity().removeMarker(marker);
			internalUpdateSection(true);
		}
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.forms.AbstractEntitySetSection#getAddAction()
	 */
	@Override
	protected IAction getAddAction() {
		Action addMarker = new Action("add", Action.AS_PUSH_BUTTON){
			/* (non-Javadoc)
			 * @see org.eclipse.jface.action.Action#run()
			 */
			@Override
			public void run() {
				Marker marker = Marker.NewInstance();
				getEntity().addMarker(marker);
				internalUpdateSection(true);
				if(! getSection().isExpanded())
					getSection().setExpanded(true);
				internalUpdateSection(true);
			}
		};
		addMarker.setToolTipText("Create a new marker");
		return addMarker;
	}

}
