// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.forms.entitysections;

import org.apache.log4j.Logger;
import org.eclipse.jface.util.IPropertyChangeListener;
import org.eclipse.jface.util.PropertyChangeEvent;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.name.Rank;
import eu.etaxonomy.taxeditor.forms.AbstractFormComposite;
import eu.etaxonomy.taxeditor.forms.TextWithLabelComposite;
import eu.etaxonomy.taxeditor.forms.termcombos.NomenclaturalStatusTypeComboComposite;
import eu.etaxonomy.taxeditor.forms.termcombos.RankComboComposite;

/**
 * @author n.hoffmann
 * @created Nov 5, 2009
 * @version 1.0
 */
public class NonViralNameDetailsComposite extends AbstractFormComposite {

	private static final Logger logger = Logger
			.getLogger(NonViralNameDetailsComposite.class);
	private Label label_parsingStatus;
	private TextWithLabelComposite text_cache;
	private RankComboComposite combo_rank;
	private TextWithLabelComposite text_uninomial;
	private TextWithLabelComposite text_infragenericEpithet;
	private TextWithLabelComposite text_specificEpithet;
	private TextWithLabelComposite text_infraspecificEpithet;
	private TextWithLabelComposite text_appendedPhrase;
	private NomenclaturalStatusTypeComboComposite combo_nomenclaturalStatus;
	private NonViralName nonViralName;
	private Composite composite_nameParts;
	private Rank rank;
	
	/**
	 * @param parent
	 * @param listener
	 * @param style
	 */
	public NonViralNameDetailsComposite(Composite parent,
			IPropertyChangeListener listener, int style) {
		super(parent, listener, style);
	}
	
	public void setInput(NonViralName name){
		nonViralName = name;
		rank = name.getRank();
		createControls(this, this, SWT.NULL);
	}
	
	private void createControls(Composite parent, IPropertyChangeListener listener, int style){
		if(composite_nameParts != null)
			composite_nameParts.dispose();
		composite_nameParts = toolkit.createComposite(this);
		composite_nameParts.setLayout(new GridLayout(2, false));
		composite_nameParts.setLayoutData(new GridData(SWT.FILL, SWT.TOP, true, false));
		
		createGenusOrUninomialControls(composite_nameParts, listener, style);
		createInfragenerericEpithetControls(composite_nameParts, listener, style);
		createSpecificEpithetControls(composite_nameParts, listener, style);
		createInfraSpecificEpithetControls(composite_nameParts, listener, style);
		
		parent.layout();
	}
	
	private void createGenusOrUninomialControls(Composite parent, IPropertyChangeListener listener, int style){		
		toolkit.createLabel(composite_nameParts, "Uninomial");
		text_uninomial = toolkit.createTextWithLabelComposite(parent, null, nonViralName.getGenusOrUninomial(), listener, style);
	}
	
	private void createInfragenerericEpithetControls(Composite parent, IPropertyChangeListener listener, int style){
		if(rank.isInfraGeneric()){
			toolkit.createLabel(composite_nameParts, "Infrageneric Epithet");
			text_infragenericEpithet = toolkit.createTextWithLabelComposite(parent, null, nonViralName.getInfraGenericEpithet(), listener, style);
		}
	}
	
	private void createSpecificEpithetControls(Composite parent, IPropertyChangeListener listener, int style){
		if(rank.isSpecies() || rank.isInfraSpecific()){
			toolkit.createLabel(composite_nameParts, "Specific Epithet");
			text_specificEpithet = toolkit.createTextWithLabelComposite(composite_nameParts, null, nonViralName.getSpecificEpithet(), this, SWT.NULL);
		}
	}
	
	private void createInfraSpecificEpithetControls(Composite parent, IPropertyChangeListener listener, int style){
		if(rank.isInfraSpecific()){
			toolkit.createLabel(composite_nameParts, "Infraspecific Epithet");
			text_infraspecificEpithet = toolkit.createTextWithLabelComposite(composite_nameParts, null, nonViralName.getInfraSpecificEpithet(), this, SWT.NULL);
		}
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.propertysheet.tabbed.section.AbstractCdmPropertySection#propertyChange(org.eclipse.jface.util.PropertyChangeEvent)
	 */
	@Override
	public void propertyChange(PropertyChangeEvent event) {
		super.propertyChange(event);
	}
}
