/**
 * 
 */
package eu.etaxonomy.taxeditor.forms.entitysections;

import java.util.Set;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.util.IPropertyChangeListener;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.widgets.Composite;

import eu.etaxonomy.cdm.model.common.IdentifiableEntity;
import eu.etaxonomy.cdm.model.common.IdentifiableSource;
import eu.etaxonomy.cdm.model.common.OriginalSourceBase;

/**
 * 
 * @author n.hoffmann
 * @created Nov 17, 2009
 * @version 1.0
 */
public class SourceSection extends AbstractEntitySetSection<IdentifiableEntity> {

	/**
	 * @param parent
	 * @param entity
	 * @param style
	 */
	public SourceSection(Composite parent, IdentifiableEntity entity,
			IPropertyChangeListener listener, int style) {
		super(parent, entity, "Sources", listener, style);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.forms.AbstractEntitySetSection#createDynamicContents()
	 */
	@Override
	protected void createDynamicContents() {
		Set<IdentifiableSource> sources = null;
		if(getEntity() != null){
			sources = getEntity().getSources();
		}
		
		if(sources == null || sources.size() == 0){
			toolkit.createLabel(container, "No citations yet.");
		}else{
			for(IdentifiableSource source : sources){
				new IdentifiableSourceComposite(container, source, new RemoveListener(source), this, SWT.NULL);
			}
		}
	}
	
	private class RemoveListener extends SelectionAdapter{
		private OriginalSourceBase source;
		
		public RemoveListener(OriginalSourceBase source){
			this.source = source;
		}
		
		/* (non-Javadoc)
		 * @see org.eclipse.swt.events.SelectionAdapter#widgetSelected(org.eclipse.swt.events.SelectionEvent)
		 */
		@Override
		public void widgetSelected(SelectionEvent e) {
			getEntity().removeSource((IdentifiableSource) source);
			internalUpdateSection(true);
		}
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.forms.AbstractEntitySetSection#getAddAction()
	 */
	@Override
	protected IAction getAddAction() {
		Action addSource = new Action("add", Action.AS_PUSH_BUTTON){
			/* (non-Javadoc)
			 * @see org.eclipse.jface.action.Action#run()
			 */
			@Override
			public void run() {
				IdentifiableSource source = IdentifiableSource.NewInstance();
				getEntity().addSource(source);
				internalUpdateSection(true);
				if(! getSection().isExpanded())
					getSection().setExpanded(true);
				internalUpdateSection(true);
			}
		};
		addSource.setToolTipText("Create a new marker");
		return addSource;
	}

}
