/**
 * 
 */
package eu.etaxonomy.taxeditor.forms.termcombos;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

import org.apache.log4j.Logger;
import org.eclipse.jface.util.IPropertyChangeListener;
import org.eclipse.jface.util.PropertyChangeEvent;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.ui.forms.events.HyperlinkAdapter;
import org.eclipse.ui.forms.events.HyperlinkEvent;
import org.eclipse.ui.forms.widgets.Hyperlink;

import eu.etaxonomy.cdm.model.common.DefinedTermBase;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.forms.AbstractFormComposite;
import eu.etaxonomy.taxeditor.preference.LanguageMenuPreferences;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * 
 * @author n.hoffmann
 * @created Nov 5, 2009
 * @version 1.0
 * @param <T>
 */
public abstract class AbstractTermComboComposite<T extends DefinedTermBase> extends AbstractFormComposite implements SelectionListener{

	private static final Logger logger = Logger.getLogger(AbstractTermComboComposite.class);
	
	T selection;
	
	private Label label;
	private Combo combo;

	private ArrayList<T> terms;

	private Comparator<T> termComparator;

	private Composite msgComposite;
	
	/**
	 * @param parent
	 * @param style
	 */
	public AbstractTermComboComposite(Composite parent, String labelString, T selection, IPropertyChangeListener listener, int visibleItems, int style) {
		super(parent, listener, style);
		
		if(labelString != null){
			label = toolkit.createLabel(this, labelString);
			label.setLayoutData(new GridData(SWT.FILL, SWT.TOP, true, false));
		}
		
        // create combo
        combo = new Combo(this, SWT.BORDER | SWT.READ_ONLY);
        combo.setLayoutData(new GridData(SWT.FILL, SWT.TOP, true, false));
        combo.setVisibleItemCount(visibleItems);
        
        populateTerms();
        
        combo.addSelectionListener(this);
        PreferencesUtil.getPreferenceStore().addPropertyChangeListener(this);
	}

	public T getSelection(){
		return selection;
	}
	
	public void setSelection(T selection){
		Listener[] listeners = combo.getListeners(SWT.Selection);
		
		for (Listener listener : listeners){
			combo.removeListener(SWT.Selection, listener);
		}
		
		combo.select(terms.indexOf(selection));
		
		for (Listener listener : listeners){
			combo.addListener(SWT.Selection, listener);
		}
	}
	
	private void populateTerms(){
		List<T> preferredTerms = preferredTerms();
		
		combo.removeAll();
		
		terms = new ArrayList<T>();
		
		int i = 0;		
		int index = 0;
		if(termComparator != null)
			Collections.sort(preferredTerms, termComparator);
		for (T term : preferredTerms) {
			String label = getLabel(term); 
			if (label == null) {
				logger.warn("No label for " + term + " - not added to combo");
				continue;
			}
			combo.add(label);
			terms.add(term);

			i++;
			if (selection != null) {
				if (selection.equals(term)) {
			 		index = i;
				}
			} else {
				// TODO isn't it better to put the last language at the top of the menu, not automatically select?
//					if (lastLanguage != null && lastLanguage.equals(language)) {
//						index = i;  
//					}
			}
		}
		
		// Check whether language is in menu
		if (msgComposite != null) {
			msgComposite.dispose();
			msgComposite = null;
		}
		if (selection != null && index == 0) {
			createTermNotInPreferredTerms(selection);
		}
		
		combo.select(index);	
	}
	
	/**
	 * @return
	 */
	protected abstract List<T> preferredTerms();
	
	/**
	 * May be overridden by derived classes if the desired label string does not
	 * reside in term.getLabel();
	 * 
	 * @param term
	 * @return
	 */
	protected String getLabel(T term){
		return term.getLabel(CdmStore.getDefaultLanguage());
	}

	private void createTermNotInPreferredTerms(T term) {
		
		msgComposite = toolkit.createComposite(this);
		GridLayout layout = new GridLayout();
		layout.numColumns = 2;
		msgComposite.setLayout(layout);
		msgComposite.setLayoutData(new GridData(GridData.GRAB_HORIZONTAL
                | GridData.GRAB_VERTICAL | GridData.HORIZONTAL_ALIGN_FILL
                | GridData.VERTICAL_ALIGN_CENTER));
		
		String langText = term.getDescription() == null ? term.getLabel() : term.getDescription();
		langText += " is not one of your preferred " + term.getClass().getSimpleName().toLowerCase() + "s. ";
		Label label = toolkit.createLabel(msgComposite, langText, SWT.WRAP);
		label.setLayoutData(new GridData(GridData.GRAB_HORIZONTAL
                | GridData.GRAB_VERTICAL | GridData.HORIZONTAL_ALIGN_FILL
                | GridData.VERTICAL_ALIGN_CENTER));
		
		Hyperlink linkEdit = toolkit.createHyperlink(msgComposite, "Edit preferences", SWT.WRAP);
		linkEdit.addHyperlinkListener(new HyperlinkAdapter() {
			/* (non-Javadoc)
			 * @see org.eclipse.ui.forms.events.HyperlinkAdapter#linkActivated(org.eclipse.ui.forms.events.HyperlinkEvent)
			 */
			@Override
			public void linkActivated(HyperlinkEvent e) {
				org.eclipse.ui.dialogs.PreferencesUtil.createPreferenceDialogOn(EditorUtil.getShell(), 
						LanguageMenuPreferences.ID, null, null).open();
			}
		});
		
		msgComposite.moveBelow(combo);
		
		pack(true);
		layout();
	}
	
	public void addSelectionListener(SelectionListener listener){
		combo.addSelectionListener(listener);
	}
	
	public void removeSelectionListener(SelectionListener listener){
		combo.removeSelectionListener(listener);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
	 */
	public void widgetSelected(SelectionEvent e) {
		selection = terms.get(combo.getSelectionIndex());
		firePropertyChangeEvent(null);
	}
	
	/* (non-Javadoc)
	 * @see java.beans.PropertyChangeListener#propertyChange(java.beans.PropertyChangeEvent)
	 */
	public void propertyChange(PropertyChangeEvent event) {
		super.propertyChange(event);
		if (event != null && PreferencesUtil.PREFERRED_TERMS_CHANGE.equals(event.getProperty())) {
			populateTerms();
		}
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.forms.AbstractFormComposite#dispose()
	 */
	@Override
	public void dispose() {
		super.dispose();
		PreferencesUtil.getPreferenceStore().removePropertyChangeListener(this);
	}
	
	// not used
	public void widgetDefaultSelected(SelectionEvent e) {}
}
