// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.tabbed;

import org.apache.log4j.Logger;
import org.eclipse.core.runtime.Assert;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CLabel;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.FormAttachment;
import org.eclipse.swt.layout.FormData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.views.properties.tabbed.AbstractPropertySection;
import org.eclipse.ui.views.properties.tabbed.ITabbedPropertyConstants;
import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage;

import eu.etaxonomy.cdm.model.taxon.TaxonBase;

/**
 * @author n.hoffmann
 * @created 05.06.2009
 * @version 1.0
 */
public class CreatedSection extends AbstractPropertySection {
	private static final Logger logger = Logger.getLogger(CreatedSection.class);

	private TaxonBase taxonBase;

	private Text createdText;
	private Text createdByText;
	
	/**
	 * 
	 */
	public CreatedSection() {}
	

    private ModifyListener listener = new ModifyListener() {
        
        public void modifyText(ModifyEvent arg0) {
//        	TaxonBasePropertySource properties = (TaxonBasePropertySource) taxonBase
//                .getAdapter(IPropertySource.class);
//            properties.setPropertyValue(TaxonBasePropertySource.P_ID_TAXONNAME,
//                labelText.getText());
        }
    };

	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.tabbed.AbstractPropertySection#createControls(org.eclipse.swt.widgets.Composite, org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage)
	 */
	@Override
	public void createControls(Composite parent, TabbedPropertySheetPage tabbedPropertySheetPage) {
		
        super.createControls(parent, tabbedPropertySheetPage);
        Composite composite = getWidgetFactory().createFlatFormComposite(parent);
        FormData data;
   
        // created
        createdText = getWidgetFactory().createText(composite, ""); //$NON-NLS-1$
   
		data = new FormData();
		data.left = new FormAttachment(0, STANDARD_LABEL_WIDTH);
		data.right = new FormAttachment(100, 0);
		data.top = new FormAttachment(0, ITabbedPropertyConstants.VSPACE);
		createdText.setLayoutData(data);
		createdText.addModifyListener(listener);		
		
		CLabel createdLabel = getWidgetFactory()
		               .createCLabel(composite, "Created:");
		
		data = new FormData();
		data.left = new FormAttachment(0, 0);
		data.right = new FormAttachment(createdText,
		       -ITabbedPropertyConstants.HSPACE);
		data.top = new FormAttachment(createdText, 0, SWT.CENTER);
		createdLabel.setLayoutData(data);
		
		// createdBy
		createdByText = getWidgetFactory().createText(composite, ""); 
        
		data = new FormData();
		data.left = new FormAttachment(0, STANDARD_LABEL_WIDTH);
		data.right = new FormAttachment(100, 0);
		data.top = new FormAttachment(0, ITabbedPropertyConstants.VSPACE);
		createdByText.setLayoutData(data);
		createdByText.addModifyListener(listener);		
		
		CLabel createdByLabel = getWidgetFactory()
		               .createCLabel(composite, "Created By:");
		
		data = new FormData();
		data.left = new FormAttachment(0, 0);
		data.right = new FormAttachment(createdByText,
		       -ITabbedPropertyConstants.HSPACE);
		data.top = new FormAttachment(createdByText, 0, SWT.CENTER);
		createdByLabel.setLayoutData(data);
		

	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.tabbed.AbstractPropertySection#refresh()
	 */
	@Override
	public void refresh() {
		super.refresh();
		createdText.setText(taxonBase.getCreated().toString());
		createdByText.setText(taxonBase.getCreatedBy() != null ? taxonBase.getCreatedBy().getUsername() : "");
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.tabbed.AbstractPropertySection#setInput(org.eclipse.ui.IWorkbenchPart, org.eclipse.jface.viewers.ISelection)
	 */
	@Override
	public void setInput(IWorkbenchPart part, ISelection selection) {
		
        super.setInput(part, selection);
        Assert.isTrue(selection instanceof IStructuredSelection);
        Object input = ((IStructuredSelection) selection).getFirstElement();
        Assert.isTrue(input instanceof TaxonBase);
        this.taxonBase = (TaxonBase) input;

		
//		super.setInput(part, selection);
	}
}
