// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.tabbed;

import org.apache.log4j.Logger;
import org.eclipse.core.runtime.Assert;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CLabel;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.views.properties.tabbed.AbstractPropertySection;
import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage;

import eu.etaxonomy.cdm.hibernate.HibernateProxyHelper;
import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.taxeditor.editor.GroupedComposite;

/**
 * @author n.hoffmann
 * @created 09.06.2009
 * @version 1.0
 */
public class NameOverviewSection extends AbstractPropertySection {
	private static final Logger logger = Logger
			.getLogger(NameOverviewSection.class);
	private TaxonBase<?> taxonBase;
	private NonViralName<?> name;
	private CLabel title;
	
	private CLabel parsingStatus;
	private Composite composite;
	private GroupedComposite groupedComposite;

	/**
	 * 
	 */
	public NameOverviewSection() {}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.tabbed.AbstractPropertySection#createControls(org.eclipse.swt.widgets.Composite, org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage)
	 */
	@Override
	public void createControls(Composite parent,
			TabbedPropertySheetPage tabbedPropertySheetPage) {
		
		super.createControls(parent, tabbedPropertySheetPage);
		
		composite = getWidgetFactory().createComposite(parent);
		composite.setLayout(new GridLayout(1, false));
		
		title = getWidgetFactory().createCLabel(composite, "", SWT.WRAP);
		parsingStatus = getWidgetFactory().createCLabel(composite, "");
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.tabbed.AbstractPropertySection#refresh()
	 */
	@Override
	public void refresh() {
		super.refresh();
		
		title.setText(name.getFullTitleCache());
		
		parsingStatus.setText(name.hasProblem() ? "Name has problems" : "Name was succesfully parsed");
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.tabbed.AbstractPropertySection#setInput(org.eclipse.ui.IWorkbenchPart, org.eclipse.jface.viewers.ISelection)
	 */
	@Override
	public void setInput(IWorkbenchPart part, ISelection selection) {
		// FIXME this is copied from AbstractNamePropertySection. We do not want duplicated code
        super.setInput(part, selection);
        Assert.isTrue(selection instanceof IStructuredSelection);
        Object input = ((IStructuredSelection) selection).getFirstElement();
        Assert.isTrue(input instanceof GroupedComposite);

        groupedComposite = (GroupedComposite) input;
        taxonBase = (TaxonBase) groupedComposite.getData();
        
        name = HibernateProxyHelper.deproxy(taxonBase.getName(), NonViralName.class);
	}

	
	
}
