/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.navigation.navigator;

import org.apache.log4j.Logger;

import eu.etaxonomy.cdm.persistence.hibernate.CdmDataChangeMap;
import eu.etaxonomy.cdm.persistence.hibernate.CdmDataChangeEvent.EventType;
import eu.etaxonomy.taxeditor.model.AbstractDataChangeBehaviour;
import eu.etaxonomy.taxeditor.model.IDataChangeBehavior;

/**
 * @author n.hoffmann
 * @created 01.04.2009
 * @version 1.0
 */
public class TaxonNavigatorDataChangeBehavior extends AbstractDataChangeBehaviour implements 
		IDataChangeBehavior {
	private static final Logger logger = Logger
			.getLogger(TaxonNavigatorDataChangeBehavior.class);

	private TaxonNavigator source;
	
	public TaxonNavigatorDataChangeBehavior(TaxonNavigator taxonNavigator) {
		source = taxonNavigator;
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.store.model.IDataChangeBehavior#isRelevant(java.lang.Object, eu.etaxonomy.cdm.persistence.hibernate.CdmCrudEvent)
	 */
	public boolean isRelevant(CdmDataChangeMap events) {
		// react on everything except load
		if(events.sizeByEventType(EventType.INSERT) > 0){
			return true;
		}else if(events.sizeByEventType(EventType.UPDATE) > 0){
			return true;
		}else if(events.sizeByEventType(EventType.DELETE) > 0){
			return true;
		}else{
			return false;
		}
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.store.model.IDataChangeBehavior#reactOnDataChange(java.lang.Object, eu.etaxonomy.cdm.persistence.hibernate.CdmCrudEvent)
	 */
	public void reactOnDataChange(CdmDataChangeMap events) {
		if(isRelevant(events)){
			source.refresh();			
			logger.info("DataStore update caused a refresh of the taxonomic tree");
		}
	}
}
