// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.datasource.wizard;

import org.eclipse.jface.wizard.Wizard;

import eu.etaxonomy.cdm.database.CdmPersistentDataSource;
import eu.etaxonomy.cdm.database.DatabaseTypeEnum;
import eu.etaxonomy.cdm.database.ICdmDataSource;
import eu.etaxonomy.taxeditor.datasource.CdmDataSourceRepository;

/**
 * @author n.hoffmann
 * @created 18.05.2009
 * @version 1.0
 */
public class CdmDataSourceWizard extends Wizard {
	
	private CdmDataSourceCredentialsWizardPage dataSourcePage;

	private CdmDataSourceTypeSelectionWizardPage dataSourceSelectionPage;
	
	private CdmPersistentDataSource dataSource;
	
	private String dataSourceName;
	
	private boolean editMode;
	
	/**
	 * @param b
	 */
	public CdmDataSourceWizard() {
		super();
		editMode = false;
		setForcePreviousAndNextButtons(true);
		setWindowTitle("Datasource Dialog");
	}
	
	/**
	 * @param b
	 */
	public CdmDataSourceWizard(CdmPersistentDataSource dataSource) {
		super();
		if(dataSource != null){
			editMode = true;
			this.dataSource = dataSource;
			dataSourceName = dataSource.getName();
		}
		setForcePreviousAndNextButtons(true);
		setWindowTitle("Datasource Dialog");
	}


	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#addPages()
	 */
	@Override
	public void addPages() {

		if(editMode){
			if(dataSource.getDatabaseType() == DatabaseTypeEnum.H2){
				dataSourcePage = new CdmDataSourceH2WizardPage(dataSource);
			}else if(dataSource.getDatabaseType() == DatabaseTypeEnum.MySQL){
				dataSourcePage = new CdmDataSourceMySQLWizardPage(dataSource);
			}else if(dataSource.getDatabaseType() == DatabaseTypeEnum.SqlServer2005){
				dataSourcePage = new CdmDataSourceSQLServerWizardPage(dataSource);
			}
			this.addPage(dataSourcePage);
		}else{
			dataSourceSelectionPage = new CdmDataSourceTypeSelectionWizardPage(dataSource);	
			this.addPage(dataSourceSelectionPage);
		}
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#performFinish()
	 */
	@Override
	public boolean performFinish() {
				
		if(editMode){
			ICdmDataSource dataSource = dataSourcePage.getDataSource();
			CdmDataSourceRepository.update(dataSourceName, dataSource);
			
			return true;
		}else{
			if(dataSourceSelectionPage.getCredentialsWizardPage() != null){
				CdmDataSourceCredentialsWizardPage credentialsWizardPage = dataSourceSelectionPage.getCredentialsWizardPage();
				CdmDataSourceRepository.save(dataSourceSelectionPage.getDataSourceName(), credentialsWizardPage.getDataSource());
				return true;
			}else{
				throw new IllegalStateException("Expected a datasource credentials page to exist");
			}
		}
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#canFinish()
	 */
	@Override
	public boolean canFinish() {
		if(editMode){
			return dataSourcePage.isPageComplete();
		}else{
			boolean result = true;
			result &= dataSourceSelectionPage.isPageComplete();
			if(dataSourceSelectionPage.getCredentialsWizardPage() != null){
				result &= dataSourceSelectionPage.getCredentialsWizardPage().isPageComplete();
			}
			return result;
		}
	}
}
