
package eu.etaxonomy.taxeditor.store.operations;

import junit.framework.Assert;

import org.eclipse.core.commands.ExecutionException;
import org.junit.BeforeClass;
import org.junit.Ignore;
import org.junit.Test;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationship;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationshipType;
import eu.etaxonomy.taxeditor.operations.ChangeConceptRelationshipTypeOperation;

/**
 * Specification for changing the concept relation between two taxa
 * 
 * @author n.hoffmann
 * @created 07.04.2009
 * @version 1.0
 */
public class ChangeConceptRelationshipTypeOperationTest extends AbstractTaxeditorOperationTest {
	
	private static Taxon relatedTaxon;

	private static TaxonRelationshipType oldRelationshipType;

	private static TaxonRelationshipType newRelationshipType;
	
	private static TaxonRelationship[] a = new TaxonRelationship[0];

	@BeforeClass
	public static void setUpBeforeClass() throws Exception {
		taxon = Taxon.NewInstance(null, null);
		relatedTaxon = Taxon.NewInstance(null, null);
		oldRelationshipType = TaxonRelationshipType.OVERLAPS();
		newRelationshipType = TaxonRelationshipType.OVERLAPS_OR_EXCLUDES();
		
		taxon.addTaxonRelation(relatedTaxon, oldRelationshipType, null, null);
		//oldTaxonRelationship = taxon.getTaxonRelations().toArray(a)[0];
		
		operation = new ChangeConceptRelationshipTypeOperation("Change Concept Relation", null, taxon, relatedTaxon, newRelationshipType, postOperation);
	}

	@Test
	@Ignore // Operation not fully implemented
	public void testExecute() throws ExecutionException {
		operation.execute(monitor, info);
		
		Assert.assertEquals(relatedTaxon, taxon.getRelationsFromThisTaxon().toArray(a)[0].getFromTaxon());
		Assert.assertEquals(newRelationshipType, taxon.getRelationsFromThisTaxon().toArray(a)[0].getType());
	}

	@Test
	@Ignore // Operation not fully implemented
	public void testUndo() throws ExecutionException {
		operation.undo(monitor, info);
		
		Assert.assertEquals(relatedTaxon, taxon.getRelationsFromThisTaxon().toArray(a)[0].getFromTaxon());
		Assert.assertEquals(oldRelationshipType, taxon.getRelationsFromThisTaxon().toArray(a)[0].getType());
	}
	
	@Test
	@Ignore // Operation not fully implemented
	public void testRedo() throws ExecutionException {
		operation.redo(monitor, info);
		
		Assert.assertEquals(relatedTaxon, taxon.getRelationsFromThisTaxon().toArray(a)[0].getFromTaxon());
		Assert.assertEquals(newRelationshipType, taxon.getRelationsFromThisTaxon().toArray(a)[0].getType());
	}

}
